@@ -16,7 +16,7 @@ import time
 
 from tempest import config
 from tempest.lib.cli import base
-from tempest.test import BaseTestCase
+from tempest import test
 from tempest.lib import exceptions as exc
 from tempest.lib.auth import IDENTITY_VERSION
 from tempest.lib.common.utils import data_utils
@@ -50,9 +50,10 @@ class ClientTestBase(base.ClientTestBase):
                     cli_dir = path
                     break
 
-        self.client_manager_admin = BaseTestCase.get_client_manager('admin')
+        self.client_manager_admin = \
+            test.BaseTestCase.get_client_manager('admin')
         auth_provider = self.client_manager_admin.auth_provider
-        self.project_network = BaseTestCase.get_tenant_network('admin')
+        self.project_network = test.BaseTestCase.get_tenant_network('admin')
 
         project_name = auth_provider.credentials.get('project_name')
         if project_name is None:
@@ -76,8 +77,13 @@ class ClientTestBase(base.ClientTestBase):
                 'project_domain_name'),
             identity_api_version=identity_api_version)
 
-    def openstack(self, *args, **kwargs):
-        return self.clients.openstack(*args, **kwargs)
+    def openstack(self, action, flags='', params='', fail_ok=False,
+                  merge_stderr=False):
+        if '--os-data-processing-api-version' not in flags:
+            flags = flags + '--os-data-processing-api-version %s' % \
+                (TEMPEST_CONF.data_processing.api_version_saharaclient)
+        return self.clients.openstack(action, flags=flags, params=params,
+                                      fail_ok=fail_ok, merge_stderr=False)
 
     def listing_result(self, command):
         command_for_item = self.openstack('dataprocessing', params=command)
@@ -203,4 +209,4 @@ class ClientTestBase(base.ClientTestBase):
         # this'll be needed as long as BaseTestCase functions
         # are used in this class, otherwise projects, users,
         # networks and routers created won't be deleted
-        BaseTestCase.clear_credentials()
+        test.BaseTestCase.clear_credentials()
