@@ -124,8 +124,12 @@ def get_base_parser():
                         nargs='?', help='Specify Sahara release')
     parser.add_argument('--report', default=False, action='store_true',
                         help='Write results of test to file')
+    parser.add_argument('--feature', '-f', default=[],
+                        nargs='?', help='Set of features to enable')
     parser.add_argument('--count', default=1, nargs='?', type=valid_count,
                         help='Specify count of runs current cases.')
+    parser.add_argument('--v2', '-2', default=False, action='store_true',
+                        help='Use APIv2')
     return parser
 
 
@@ -155,12 +159,15 @@ def main():
     version = args.plugin_version
     release = args.release
     report = args.report
+    features = args.feature
     count = args.count
+    use_api_v2 = args.v2
 
     auth_values = utils.get_auth_values(cloud_config, args)
 
     scenario_arguments = utils.get_default_templates(plugin, version, release,
-                                                     scenario_arguments)
+                                                     scenario_arguments,
+                                                     features)
 
     files = get_scenario_files(scenario_arguments)
 
@@ -171,7 +178,7 @@ def main():
 
     params_for_login = {'credentials': auth_values}
     config = utils.generate_config(files, template_variables, params_for_login,
-                                   verbose_run)
+                                   verbose_run, features)
 
     # validate config
     validation.validate(config)
@@ -187,7 +194,7 @@ def main():
         testcases.extend(config['clusters'])
 
     test_dir_path = utils.create_testcase_file(testcases, credentials, network,
-                                               report)
+                                               report, use_api_v2=use_api_v2)
 
     # run tests
     concurrency = config.get('concurrency')
